/*
 * Copyright (c) 2019 DuckDuckGo
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.duckduckgo.app.global.exception

import androidx.room.Entity
import androidx.room.PrimaryKey
import com.duckduckgo.app.browser.BuildConfig
import java.text.SimpleDateFormat
import java.util.*

@Entity
data class UncaughtExceptionEntity(
    @PrimaryKey(autoGenerate = true) val id: Long = 0,
    val exceptionSource: UncaughtExceptionSource,
    val message: String,
    val timestamp: Long = System.currentTimeMillis(),
    val version: String = BuildConfig.VERSION_NAME
) {

    fun formattedTimestamp(): String = formatter.format(Date(timestamp))

    companion object {
        val formatter: SimpleDateFormat = SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ssZ", Locale.US).apply {
            timeZone = TimeZone.getTimeZone("UTC")
        }
    }
}
